package figurasgeometricas;

/**
 * Classe que descreve um retângulo.
 * @author prof@caetano.eng.br
 */
public class Retangulo {
    
    // Coordenadas do ponto inferior esquerdo
    private int x1;
    private int y1;
    // Coordenadas do ponto superior direito
    private int x2;
    private int y2;

    /**
     * Construtor Replicador
     * @param o Objeto a ser copiado
     */
    public Retangulo ( Retangulo o ) {
        this(o.x1, o.y1, 0, 0);
        x2 = o.x2;
        y2 = o.y2;
    }
    
    /**
     * Construtor do retângulo
     * @param x valor de X do canto inferior esquerdo
     * @param y valor de Y do canto inferior esquerdo
     * @param base largura da base do retângulo
     * @param altura altura do retângulo
     */
    public Retangulo(int x, int y, int base, int altura) {
        x1 = x;
        y1 = y;
        x2 = x1 + base;
        y2 = y1 + altura;
    }


// Versão Alternativa do construtor que recebia o valor dos dois cantos
/*
    public Retangulo(int x1, int y1, int x2, int y2) {
        this.x1 = x1;
        this.y1 = y1;
        this.x2 = x2;
        this.y2 = y2;
    }
*/    

    /**
     * Imprime informações do retângulo
     * @return texto contendo a descrição do retângulo
     */
    @Override
    public String toString() {
        return "Retangulo{" + "x1=" + x1 + ", y1=" + y1 + ", x2=" + x2 + ", y2=" + y2 + '}';
    }

    /**
     * Calcula o perímetro do retângulo.
     * @return comprimento do perímetro do retângulo.
     */
    public int perimetro() {
        int base = x2 - x1;
        int altura = y2 - y1;
        return 2*base + 2*altura;
    }

    /**
     * Calcula a área do retângulo
     * @return área do retângulo.
     */    
    public int area() {
        int base = x2 - x1;
        int altura = y2 - y1;
        return base * altura;
    }
    
}

